@@ -3,12 +3,13 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Carp;
 use Furl;
 use HTTP::Request;
 use JSON;
+use MIME::Base64;
 use Moo;
 use POSIX qw(setlocale LC_TIME strftime);
 use Scalar::Util qw(reftype);
@@ -334,25 +335,42 @@ sub _except_type {
     my $v = shift;
     my $res;
     if (ref $v eq 'HASH') {
-        for my $k (keys %{$v}) {
-            my $with_type = $v->{$k};
-            my ($k2) = keys %{$with_type};
-            $res->{$k} = $with_type->{$k2};
+        for my $key (keys %{$v}) {
+            my $value = $v->{$key};
+            $res->{$key} = _rm_type($value);
         }
     } elsif (ref $v eq 'ARRAY') {
         for my $w (@{$v}) {
-            my $with_out_type;
-            for my $k (keys %{$w}) {
-                my $with_type = $w->{$k};
-                my ($k2) = keys %{$with_type};
-                $with_out_type->{$k} = $with_type->{$k2};
-            }
-            push @{$res}, $with_out_type;
+            push @{$res}, _except_type($w);
         }
     }
     return $res;
 }
 
+sub _rm_type {
+    my $v = shift;
+    my ($type, $value) = %$v;
+    my $res;
+    if ($type eq 'L') {
+        for my $i (@$value) {
+            push @$res, _rm_type($i);
+        }
+        return $res;
+    }
+    elsif ($type eq 'M') {
+        for my $i (keys %$value) {
+            $res->{$i} = _rm_type($value->{$i});
+        }
+        return $res;
+    }
+    elsif ($type eq 'B') {
+        return MIME::Base64::decode_base64($value);
+    }
+    else {
+        return $value;
+    }
+}
+
 sub _error_content {
     my ($self, $res, $decoded) = @_;
 
@@ -1395,6 +1413,10 @@ Puts or Deletes multiple items in one or more tables.
 
 =back
 
+=head1 CONTRIBUTORS
+
+kablamo
+
 =head1 LICENSE
 
 Copyright (C) Kazuhiro Shibuya.
